package entry

import org.apache.flink.streaming.api.scala.StreamExecutionEnvironment
import tools.kafka.KafkaConsumer
import org.apache.flink.api.scala._
import tools.dataformat.Data
import tools.json.Jackson
import tools.properties.PropertiesTools
import java.util.Properties
import scala.collection.mutable

/**
 * Created with IntelliJ IDEA.
 * Class: Entry
 * Description: 程序入口
 * User: lin
 * Date: 2021-06-04
 * Time: 13:46
 */
object Entry {
  def main(args: Array[String]): Unit = {

    val properties: Properties = PropertiesTools.getProperties

    //     消费京东和淘宝的数据
    val tb_topic: String = properties.getProperty("kafka.tb.topic")
    val tb_group: String = properties.getProperty("kafka.tb.consumer.group")
    val jd_topic: String = properties.getProperty("kafka.jd.topic")
    val jd_group: String = properties.getProperty("kafka.jd.consumer.group")

    //   配置环境
    val environment = StreamExecutionEnvironment.getExecutionEnvironment
    //    .enableCheckpointing(1000L)

    //   kafka源
    val tb_consumer = KafkaConsumer.getConsumer(tb_topic, tb_group)
    val jd_consumer = KafkaConsumer.getConsumer(jd_topic, jd_group)

    tb_consumer.setStartFromEarliest()
    jd_consumer.setStartFromEarliest()

    // 清洗淘宝数据
    val tbSource = environment
      .addSource(tb_consumer)
      .map(tb => {
        val res = mutable.Map[String, String]()
        Jackson.parseAllKey(tb, res)
      })
      .map(x => Data.formatTBData(x))

    // 清洗京东数据
    val jdSource = environment
      .addSource(jd_consumer)
      .map(x => {
        val res = mutable.Map[String, String]()
        Jackson.parseAllKey(x, res)
      })
      .map(x => Data.formatJDData(x))
    // 合并流
    val ds = tbSource.union(jdSource)


    //存入ES
    ds
      //      .map(x => SaveData.saveToES(x))
      .executeAndCollect()
      .foreach(println)

    //        environment.execute("jingdong")
  }
}
